{% load i18n %}
{% load navactive %}

{% if perms.taxsystem.create_access %}
    <li class="nav-item">
        <a class="nav-link py-0" href="{% url 'taxsystem:add_corp' %}">
            <span class="btn btn-success">{% translate 'Add Corporation' %}</span>
        </a>
    </li>
    <li class="nav-item">
        <a class="nav-link py-0" href="{% url 'taxsystem:add_alliance' %}">
            <span class="btn btn-success">{% translate 'Add Alliance' %}</span>
        </a>
    </li>
{% endif %}

{% if request.resolver_match.url_name == "payments" %}
    <li class="nav-item">
        <a class="nav-link py-0" href="{% url 'taxsystem:manage_owner' owner_id=owner.eve_id %}">
            <span class="btn btn-success">{% translate 'Manage Tax System' %}</span>
        </a>
    </li>
{% endif %}
