{% extends 'taxsystem/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}

{% block page_title %}
    {{ title }} ⋗ {% translate "Tax System" %}
{% endblock %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block taxsystem_block %}
<div class="card">
    <div class="card-header bg-primary rounded-top d-flex align-items-center">
        <h3 class="me-3">{% translate "Account Status" %}</h3>
    </div>
    <div class="card-body">
        {% include 'taxsystem/partials/view-account/account.html' %}
    </div>
</div>
{% endblock %}

{% block extra_css %}
    {% include 'taxsystem/bundles/datatables-2-css.html' with extColumnControl=True %}
    {% include 'taxsystem/bundles/aa-taxsystem-css.html' %}
{% endblock %}

{% block extra_javascript %}
    {% include 'taxsystem/bundles/aa-taxsystem-js.html' %}
    {% include 'taxsystem/bundles/datatables-2-js.html' with extColumnControl=True %}
    {% include 'taxsystem/bundles/view-payments-js.html' %}
{% endblock extra_javascript %}

{% block extra_script %}
{% endblock extra_script %}
